<?php

namespace Litecms\Meeting\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Meeting\Models\Meeting;

class MeetingPolicy
{

    /**
     * Determine if the given user can view the meeting.
     *
     * @param UserPolicy $user
     * @param Meeting $meeting
     *
     * @return bool
     */
    public function view(UserPolicy $user, Meeting $meeting)
    {
        if ($user->canDo('meeting.meeting.view') && $user->isAdmin()) {
            return true;
        }

        return $meeting->user_id == user_id() && $meeting->user_type == user_type();
    }

    /**
     * Determine if the given user can create a meeting.
     *
     * @param UserPolicy $user
     * @param Meeting $meeting
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('meeting.meeting.create');
    }

    /**
     * Determine if the given user can update the given meeting.
     *
     * @param UserPolicy $user
     * @param Meeting $meeting
     *
     * @return bool
     */
    public function update(UserPolicy $user, Meeting $meeting)
    {
        if ($user->canDo('meeting.meeting.edit') && $user->isAdmin()) {
            return true;
        }

        return $meeting->user_id == user_id() && $meeting->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given meeting.
     *
     * @param UserPolicy $user
     * @param Meeting $meeting
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Meeting $meeting)
    {
        return $meeting->user_id == user_id() && $meeting->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given meeting.
     *
     * @param UserPolicy $user
     * @param Meeting $meeting
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Meeting $meeting)
    {
        if ($user->canDo('meeting.meeting.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given meeting.
     *
     * @param UserPolicy $user
     * @param Meeting $meeting
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Meeting $meeting)
    {
        if ($user->canDo('meeting.meeting.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
